@@ -11,4 +11,6 @@ pub enum Error {
     FileNameStrConversionFailure(PathBuf),
     #[error("could not convert path (Path) to &str: {0}")]
     PathToStrConversionFailure(PathBuf),
+    #[error("could not find home directory")]
+    HomeDirNotFound,
 }
